==> netifyd-2021-05-19-v3.07.tar.xz: netifyd-2021-05-19-v3.07/src/nd-plugin-example/include/plugin-example.h <==
// Netify Agent
// Copyright (C) 2015-2019 eGloo Incorporated <http://www.egloo.ca>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef _ND_PLUGIN_EXAMPLE_H
#define _ND_PLUGIN_EXAMPLE_H

class ndPluginExampleService : public ndPluginService
{
public:
    ndPluginExampleService(const string &tag);
    virtual ~ndPluginExampleService();

    virtual void *Entry(void);

    virtual void Reload(void) { nd_dprintf("%s: Reloading...\n", tag.c_str()); }
};

class ndPluginExampleTask : public ndPluginTask
{
public:
    ndPluginExampleTask(const string &tag);
    virtual ~ndPluginExampleTask();

    virtual void *Entry(void);

    virtual void Reload(void) { nd_dprintf("%s: Reloading...\n", tag.c_str()); }
};

class ndPluginExampleDetection : public ndPluginDetection
{
public:
    ndPluginExampleDetection(const string &tag);
    virtual ~ndPluginExampleDetection();

    virtual void *Entry(void);

    virtual void Reload(void) { nd_dprintf("%s: Reloading...\n", tag.c_str()); }

    virtual void ProcessFlow(const ndFlow *flow);
};

#endif // _ND_PLUGIN_EXAMPLE_H
// vi: expandtab shiftwidth=4 softtabstop=4 tabstop=4

==> netifyd-2021-11-17-v3.09.tar.xz: netifyd-2021-11-17-v3.09/src/nd-plugin-example/include/plugin-example.h <==
// Netify Agent
// Copyright (C) 2015-2019 eGloo Incorporated <http://www.egloo.ca>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef _ND_PLUGIN_EXAMPLE_H
#define _ND_PLUGIN_EXAMPLE_H

class ndPluginExampleService : public ndPluginService
{
public:
    ndPluginExampleService(const string &tag);
    virtual ~ndPluginExampleService();

    virtual void *Entry(void);

    virtual void GetVersion(string &version) { version = PACKAGE_VERSION; }
};

class ndPluginExampleTask : public ndPluginTask
{
public:
    ndPluginExampleTask(const string &tag);
    virtual ~ndPluginExampleTask();

    virtual void *Entry(void);

    virtual void GetVersion(string &version) { version = PACKAGE_VERSION; }
};

class ndPluginExampleDetection : public ndPluginDetection
{
public:
    ndPluginExampleDetection(const string &tag);
    virtual ~ndPluginExampleDetection();

    virtual void *Entry(void);

    virtual void ProcessFlow(ndFlow *flow);

    virtual void GetVersion(string &version) { version = PACKAGE_VERSION; }
};

class ndPluginExampleStats : public ndPluginStats
{
public:
    ndPluginExampleStats(const string &tag);
    virtual ~ndPluginExampleStats();

    virtual void *Entry(void);

    virtual void ProcessStats(const nd_packet_stats &pkt_totals);
    virtual void ProcessStats(const string &iface, const nd_packet_stats *pkt_stats, const nd_flow_map *flows);

    virtual void GetVersion(string &version) { version = PACKAGE_VERSION; }
};

#endif // _ND_PLUGIN_EXAMPLE_H
// vi: expandtab shiftwidth=4 softtabstop=4 tabstop=4
